==> aws-cdk.aws-apigatewayv2-authorizers-1.148.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.userPoolClients))
        require("@aws-cdk/aws-cognito/.warnings.jsii.js")._aws_cdk_aws_cognito_IUserPoolClient(p.userPoolClients);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.responseTypes))
        _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(p.responseTypes);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpIamAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpIamAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-apigatewayv2-authorizers-1.152.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.userPoolClients))
        require("@aws-cdk/aws-cognito/.warnings.jsii.js")._aws_cdk_aws_cognito_IUserPoolClient(p.userPoolClients);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.responseTypes))
        _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(p.responseTypes);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpIamAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpIamAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer };
module.exports.DeprecationError = DeprecationError;
